#ifndef _ATTENUATION_H
#define _ATTENUATION_H

#include <stdio.h>

#define ATTEN_MAX_LEVELS 100
#define FREEZING_K 273.16
#define SPEED_OF_LIGHT 2.998e8

#define LIEBE_COMMENT "the millimeter-wave propagation model of Liebe (1985, Radio Sci. 20(5), 1069-1089)."

#define MANABE_LIEBE_HUFFORD_COMMENT "the double-Debye formulation of Manabe, Liebe and Hufford (1987, Conf. Dig. 12th Int. Conf Infrared & Millimeter Waves, Lake Buena Vista, Dec. 14-18); see also Liebe, Manabe and Hufford (1989, IEEE Trans. AP 37(12), 1617-1623)."

typedef double afloat;

typedef struct {
  afloat r, i;
} acomplex;

afloat saturation_vapour_pressure(afloat temperature_K);

/* Returns one-way specific attenuation in dB/km */
afloat liebe_attenuation(afloat frequency_GHz,
			 afloat temperature_K,
			 afloat pressure_Pa,
			 afloat vapour_pressure_Pa);

/* Relative humidity RH is dimensionless, i.e. RH=1 corresponds to
   saturation (100% humidity). */
#define liebe_attenuation_RH(f, T, p, RH) \
  liebe_attenuation(f, T, p, (RH) * saturation_vapour_pressure(T))

void liebe_attenuation_profile(/* in */ afloat *height_m,
			       afloat *pressure_Pa,
			       afloat *temperature_K,
			       afloat *vapour_pressure_Pa,
			       int nlevels,
			       afloat frequency_GHz,
			       /* out */ afloat *attenuation_dB,
			       afloat *attenuation_dB_km);

acomplex manabe_liebe_hufford_dielectric(afloat temperature_K,
					 afloat frequency_GHz);

acomplex dielectric_K(afloat er, afloat ei);
#define dielectric_K_c(e) dielectric_K((e).r, (e).i)

afloat dielectric_parameter(afloat er, afloat ei);
#define dielectric_parameter_c(e) dielectric_parameter((e).r, (e).i)

#define liquid_attenuation(K_i, frequency_GHz) (- 8.186e-2 * (K_i) * (frequency_GHz) * 1.0e9 / SPEED_OF_LIGHT);

#endif
