#include <stdio.h>
#include <stdlib.h>
#include "ddh_attenuation.h"
#include "attenuation.h"

void
__ddh_attenuation_profile(DDHday *data,
			  float frequency_GHz,
			  int n,
			  float *attenuation_dB,
			  float *attenuation_dB_km,
			  int is_saturated)
{
  afloat H[DDH_MAX_LEVELS+1];
  afloat P[DDH_MAX_LEVELS+1];
  afloat T[DDH_MAX_LEVELS+1];
  afloat E[DDH_MAX_LEVELS+1];
  afloat attenuation[DDH_MAX_LEVELS+1];
  afloat attenuation_rate[DDH_MAX_LEVELS+1];
  float epsilon = 0.622;

  int j;

  H[0] = 0.0;
  T[0] = data->T[n][0];
  P[0] = data->P[n][0] / data->sigma0;
  if (is_saturated) {
    E[0] = saturation_vapour_pressure(T[0]);
    for (j = 1; j <= data->nlevels; j++) {
      H[j] = data->H[n][j-1];
      T[j] = data->T[n][j-1];
      P[j] = data->P[n][j-1];
      E[j] = saturation_vapour_pressure(data->T[n][j-1]);
    }
  }
  else {
    E[0] = data->Q[n][0] * P[0] / epsilon;
    for (j = 1; j <= data->nlevels; j++) {
      H[j] = data->H[n][j-1];
      T[j] = data->T[n][j-1];
      P[j] = data->P[n][j-1];
      E[j] = data->Q[n][j-1] * P[j] / epsilon;
    }
  }

  liebe_attenuation_profile(H, P, T, E, data->nlevels+1,
			    frequency_GHz, attenuation,
			    attenuation_rate);
  for (j = 0; j < data->nlevels; j++) {
    attenuation_dB[j] = attenuation[j+1];
  }

  if (attenuation_dB_km) {
    for (j = 0; j < data->nlevels; j++) {
      attenuation_dB_km[j] = attenuation_rate[j+1];
    }
  }
}

void
ddh_liquid_profile(DDHday *data,
	       float frequency_GHz,
	       int n,
	       float *K2,
	       float *liqud_atten_dB_km_g_m3)
{
  int k;
  for (k = 0; k < data->nlevels; k++) {
    acomplex e = manabe_liebe_hufford_dielectric(data->T[n][k],
						 frequency_GHz);
    acomplex K = dielectric_K_c(e);
    K2[k] = K.r*K.r + K.i*K.i; /*  dielectric_parameter_c(e); */
    liqud_atten_dB_km_g_m3[k] = liquid_attenuation(K.i, frequency_GHz);
  }
}
